==> tuia-explore-center-api-0.0.1-20190529.120309-28-sources.jar: cn/tuia/explore/center/api/dto/rsp/MessageDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: MessageDto.java , v 0.1 2019-05-29 09:48 ElinZhou Exp $
 */
public class MessageDto implements Serializable {

    private static final long serialVersionUID = -3105406969336267802L;
    private long msgId;

    private String title;

    private String content;

    private String icon;

    private Date time;

    private String jumpUrl;

    private boolean readed;

    public MessageDto(String title, String content, String icon, String jumpUrl) {
        this.title = title;
        this.content = content;
        this.icon = icon;
        this.jumpUrl = jumpUrl;
    }

    public long getMsgId() {
        return msgId;
    }

    public void setMsgId(long msgId) {
        this.msgId = msgId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public boolean isReaded() {
        return readed;
    }

    public void setReaded(boolean readed) {
        this.readed = readed;
    }
}

==> tuia-explore-center-api-0.0.1-20190530.113355-37-sources.jar: cn/tuia/explore/center/api/dto/rsp/MessageDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: MessageDto.java , v 0.1 2019-05-29 09:48 ElinZhou Exp $
 */
public class MessageDto implements Serializable {

    private static final long serialVersionUID = -3105406969336267802L;
    private long msgId;

    private String title;

    private String content;

    private String icon;

    private Date time;

    private String jumpUrl;

    private boolean readed;

    private long userId;

    public MessageDto(String title, String content, String icon, String jumpUrl, long userId) {
        this.title = title;
        this.content = content;
        this.icon = icon;
        this.jumpUrl = jumpUrl;
        this.userId = userId;
    }

    public long getMsgId() {
        return msgId;
    }

    public void setMsgId(long msgId) {
        this.msgId = msgId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public Date getTime() {
        return time;
    }

    public void setTime(Date time) {
        this.time = time;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public boolean isReaded() {
        return readed;
    }

    public void setReaded(boolean readed) {
        this.readed = readed;
    }

    public long getUserId() {
        return userId;
    }

    public void setUserId(long userId) {
        this.userId = userId;
    }
}
